@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: microsleep.c,v 6.4.2.1 2002/10/09 19:48:52 brbarret Exp $
+ * $Id: microsleep.c,v 6.9 2003/10/11 19:15:35 brbarret Exp $
  * 
  *	Function:	- higher precision sleep (microseconds)
  *			- uses select() timeout value
@@ -26,11 +24,15 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/time.h>
+#include <unistd.h>
 
-#if LAM_NEED_SYS_SELECT_H
+#if defined(HAVE_SYS_SELECT_H) && HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
 
+#include <laminternal.h>
+
+
 int
 microsleep(unsigned int	usec)
 {
